@@ -605,6 +605,11 @@ def deploy(
     help='Verbose printing',
     show_default=True
     )
+@click.option('--backwards', '-b',
+    is_flag=True, default=False,
+    help='Whether or not the graph must be shown backwards',
+    show_default=True
+    )
 @click.option('--exclude-external-dependencies/--include-external-dependencies', '-x/-i',
     is_flag=True, default=True,
     help='Whether or not external dependencies must be ignored',
@@ -615,13 +620,14 @@ def deploy(
     )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
 @click.version_option(version=__version__)
-def show_graph(verbose, exclude_external_dependencies, working_dir, terragrunt_args):
+def show_graph(verbose, backwards, exclude_external_dependencies, working_dir, terragrunt_args):
     """ Shows the dependencies of a project """
 
     check_latest_version(verbose)
 
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.show_graph(
+        backwards=backwards,
         exclude_external_dependencies=exclude_external_dependencies,
         working_dir=working_dir,
         terragrunt_args=terragrunt_args,
