@@ -44,11 +44,11 @@ class TgWrap():
         # Check if the "TERRAGRUNT_SOURCE" environment variable is set
         env_var = "TERRAGRUNT_SOURCE"
         if env_var in os.environ:
-            self.printer.bold(
+            self.printer.warning(
                 f"'{env_var}' environment variable is set with address: '{os.environ[env_var]}'!"
                 )
         else:
-            self.printer.bold(
+            self.printer.success(
                 f"No '{env_var}' variable is set, so the sources as defined in terragrunt.hcl files will be used as is!"
                 )
 
@@ -150,7 +150,7 @@ class TgWrap():
 
         return groups
 
-    def _get_di_graph(self, working_dir=None):
+    def _get_di_graph(self, backwards=False, working_dir=None):
         """ Gets the directed graph of terragrunt dependencies, and parse it into a graph object """
         graph = None
         try:
@@ -169,8 +169,12 @@ class TgWrap():
 
             f.flush()
 
-            # Read the directed graph and reverse it
-            graph = nx.DiGraph(nx.nx_pydot.read_dot(f.name)).reverse()
+            graph = nx.DiGraph(nx.nx_pydot.read_dot(f.name))
+            if not backwards:
+                # For regular operations the graph must be reversed
+                graph = graph.reverse()
+            else:
+                self.printer.verbose("Graph will be interpreted backwards!")
         except TypeError as e:
             self.printer.error('terragrunt has problems generating the graph, check the dependencies please!')
             self.printer.error("once fixed, you can run 'tgwrap show-graph' to verify.")
@@ -301,7 +305,8 @@ class TgWrap():
             stop_processing = True
         finally:
             if error_msg:
-                output = f'{{"exception": "{error_msg}"}}'
+                # output = f'{{"exception": "{error_msg}"}}'
+                output = json.dumps({"exception": error_msg})
 
             try:
                 # communicate the results if desired
@@ -315,19 +320,21 @@ class TgWrap():
 
             if semaphore:
                 semaphore.release()
-
-            os.remove(f.name)
+            try:
+                os.remove(f.name)
+            except Exception:
+                pass
 
         return stop_processing
 
     def _run_di_graph(
         self, command, exclude_external_dependencies, start_at_step, dry_run,
         parallel_execution=False, ask_for_confirmation=False, collect_output_file=None,
-        working_dir=None,
+        backwards=False, working_dir=None,
         ):
         "Runs the desired command in the directories as defined in the directed graph"
 
-        graph = self._get_di_graph(working_dir=working_dir)
+        graph = self._get_di_graph(backwards=backwards, working_dir=working_dir)
 
         # first go through the groups and clean up where needed
         groups = self._prepare_groups(
@@ -550,6 +557,7 @@ class TgWrap():
             self.printer.verbose(
                 f'This command will be executed for each individual module:\n$ {cmd}'
                 )
+
             self._run_di_graph(
                 command=cmd,
                 exclude_external_dependencies=exclude_external_dependencies,
@@ -557,6 +565,7 @@ class TgWrap():
                 ask_for_confirmation=(not auto_approve),
                 dry_run=dry_run,
                 start_at_step=start_at_step,
+                backwards=True if command.lower() in ['destroy'] else False
             )
         else:
             if dry_run:
@@ -705,7 +714,7 @@ class TgWrap():
                             self.printer.warning(f'Planfile for module {module} is empty')
                     except json.decoder.JSONDecodeError as e:
                         raise Exception(
-                            f"Planfile for {module} was not proper json, further analysis not possible:\n{plan_file[:100]}"
+                            f"Exception detected or planfile for {module} was not proper json, further analysis not possible:\n{plan_file[:200]}"
                             ) from e
         finally:
             os.remove(f.name)
@@ -956,7 +965,7 @@ locals {{
             except Exception:
                 pass
 
-    def show_graph(self, exclude_external_dependencies, working_dir, terragrunt_args):
+    def show_graph(self, backwards, exclude_external_dependencies, working_dir, terragrunt_args):
         """ Shows the dependencies of a project """
 
         self.printer.verbose(f"Attempting to show dependencies")
@@ -964,7 +973,7 @@ locals {{
             self.printer.verbose(f"- with additional parameters: {' '.join(terragrunt_args)}")
 
         "Runs the desired command in the directories as defined in the directed graph"
-        graph = self._get_di_graph(working_dir=working_dir)
+        graph = self._get_di_graph(backwards=backwards, working_dir=working_dir)
 
         # first go through the groups and clean up where needed
         groups = self._prepare_groups(
